@@ -4,7 +4,7 @@ use blib;
 use Storable qw( freeze thaw );
 use Regexp::Copy qw(re_copy); 
 
-use Test::More tests => 5;
+use Test::More tests => 6;
 
 ok(1,"we loaded fine...");
 
@@ -32,3 +32,12 @@ if ($@) {
 my $deep = { my => { your => { this => { that => bless({ this => qr/^\/(index\.html|value\.html)/ },'App') } } } };
 my $clone = thaw( freeze( $deep ) );
 is_deeply($clone,$deep,"deeper data structures");
+
+my $nullre = qr//;
+my $resul  = qr/I once was a fishermans son!/;
+eval {
+  re_copy($nullre, $resul);
+};
+
+ok($resul eq '(?-xism:)',"copied null regex");
+
